==> PackagedAuto-1.18.2-3.1.14.53-sources.jar: thelm/packagedauto/block/CrafterBlock.java <==
package thelm.packagedauto.block;

import net.minecraft.core.BlockPos;
import net.minecraft.world.item.BlockItem;
import net.minecraft.world.item.Item;
import net.minecraft.world.level.Level;
import net.minecraft.world.level.block.SoundType;
import net.minecraft.world.level.block.entity.BlockEntity;
import net.minecraft.world.level.block.entity.BlockEntityTicker;
import net.minecraft.world.level.block.entity.BlockEntityType;
import net.minecraft.world.level.block.state.BlockBehaviour;
import net.minecraft.world.level.block.state.BlockState;
import net.minecraft.world.level.material.Material;
import thelm.packagedauto.PackagedAuto;
import thelm.packagedauto.block.entity.BaseBlockEntity;
import thelm.packagedauto.block.entity.CrafterBlockEntity;

public class CrafterBlock extends BaseBlock {

	public static final CrafterBlock INSTANCE = new CrafterBlock();
	public static final Item ITEM_INSTANCE = new BlockItem(INSTANCE, new Item.Properties().m_41491_(PackagedAuto.CREATIVE_TAB)).setRegistryName("packagedauto:crafter");

	protected CrafterBlock() {
		super(BlockBehaviour.Properties.m_60939_(Material.f_76279_).m_60913_(15F, 25F).m_60918_(SoundType.f_56743_));
		setRegistryName("packagedauto:crafter");
	}

	@Override
	public CrafterBlockEntity m_142194_(BlockPos pos, BlockState state) {
		return CrafterBlockEntity.TYPE_INSTANCE.m_155264_(pos, state);
	}

	@Override
	public <T extends BlockEntity> BlockEntityTicker<T> m_142354_(Level level, BlockState state, BlockEntityType<T> blockEntityType) {
		return BaseBlockEntity::tick;
	}
}

==> PackagedAuto-1.18.2-3.1.14.58-sources.jar: thelm/packagedauto/block/CrafterBlock.java <==
package thelm.packagedauto.block;

import net.minecraft.core.BlockPos;
import net.minecraft.world.item.BlockItem;
import net.minecraft.world.item.Item;
import net.minecraft.world.level.Level;
import net.minecraft.world.level.block.SoundType;
import net.minecraft.world.level.block.entity.BlockEntity;
import net.minecraft.world.level.block.entity.BlockEntityTicker;
import net.minecraft.world.level.block.entity.BlockEntityType;
import net.minecraft.world.level.block.state.BlockBehaviour;
import net.minecraft.world.level.block.state.BlockState;
import net.minecraft.world.level.material.Material;
import thelm.packagedauto.PackagedAuto;
import thelm.packagedauto.block.entity.BaseBlockEntity;
import thelm.packagedauto.block.entity.CrafterBlockEntity;

public class CrafterBlock extends BaseBlock {

	public static final CrafterBlock INSTANCE = new CrafterBlock();
	public static final Item ITEM_INSTANCE = new BlockItem(INSTANCE, new Item.Properties().tab(PackagedAuto.CREATIVE_TAB)).setRegistryName("packagedauto:crafter");

	protected CrafterBlock() {
		super(BlockBehaviour.Properties.of(Material.METAL).strength(10F, 15F).sound(SoundType.METAL));
		setRegistryName("packagedauto:crafter");
	}

	@Override
	public CrafterBlockEntity newBlockEntity(BlockPos pos, BlockState state) {
		return CrafterBlockEntity.TYPE_INSTANCE.create(pos, state);
	}

	@Override
	public <T extends BlockEntity> BlockEntityTicker<T> getTicker(Level level, BlockState state, BlockEntityType<T> blockEntityType) {
		return BaseBlockEntity::tick;
	}
}
